@@ -1,3 +1,7 @@
+from dataclasses import dataclass
+
+
+@dataclass(frozen=True)
 class EnvironmentalVariablesEnum:
     PIP_URL = "PIP_URL"
     PIP_KEY = "PIP_KEY"
