@@ -56,7 +56,10 @@ class BuildingBlockAvailabilityComponent(BaseScoreComponent):
                 ratio_in_stock = sum(in_stock) / len(in_stock)
                 ratios.append(ratio_in_stock)
 
-        max_ratio = max(ratios)  # Take the best.
+        if len(ratios) > 0:
+            max_ratio = max(ratios)  # Take the best.
+        else:
+            max_ratio = 0  # No building blocks, return the lowest possible score.
 
         return max_ratio
 
