@@ -22,7 +22,10 @@ class BaseROCSComponent(BaseScoreComponent):
         # NOTE: valid_idxs are determined with RDKit not with Open Eye
         valid_smiles = self._chemistry.mols_to_smiles(molecules)
         score = self._calculate_omega_score(valid_smiles, step)
-        score = self._transformation_function(score, self.parameters.specific_parameters)
+        transform_params = self.parameters.specific_parameters.get(
+            self.component_specific_parameters.TRANSFORMATION, {}
+        )
+        score = self._transformation_function(score, transform_params)
         score_summary = ComponentSummary(total_score=score, parameters=self.parameters)
         return score_summary
 
