@@ -20,8 +20,7 @@ class TransformationFactory:
             enum.RIGHT_STEP: self.right_step,
             enum.LEFT_STEP: self.left_step,
             enum.STEP: self.step,
-            enum.CUSTOM_INTERPOLATION: self.custom_interpolation,
-            enum.CUSTOM_MAPPING: self.custom_mapping
+            enum.CUSTOM_INTERPOLATION: self.custom_interpolation
         }
         return transformation_list
 
@@ -141,11 +140,3 @@ class TransformationFactory:
         transformed = transformation(predictions)
 
         return transformed
-
-    def custom_mapping(self, predictions: list, parameters: dict) -> np.array:
-        "A custom mapping of string predictions to user-defined values."
-        mapping = parameters[TransformationParametersEnum.VALUE_MAPPING]
-
-        transformed = [mapping.get(val, 0.0) for val in predictions]
-
-        return np.array(transformed, dtype=np.float32)
